@@ -26,6 +26,7 @@ import geogebra.main.Application;
 import geogebra.main.MyError;
 
 import java.awt.BorderLayout;
+import java.awt.Font;
 import java.awt.SystemColor;
 import java.awt.dnd.DropTarget;
 import java.awt.event.ActionEvent;
@@ -171,8 +172,19 @@ public class AlgebraInput extends  JPanel implements ActionListener, KeyListener
 
 
 	public void updateFonts() {
-		inputField.setFont(app.getBoldFont());		
-		inputLabel.setFont(app.getPlainFont());
+		
+		Font bf = app.getBoldFont();
+		Font pf = app.getPlainFont();
+		
+		// needed for Armenian
+		if (pf.canDisplayUpTo(inputLabel.getText()) != -1) {
+			pf = app.getFontCanDisplay(inputLabel.getText());
+		}
+		
+		inputField.setFont(bf);		
+		inputLabel.setFont(pf);
+		
+		inputField.setPopupsFont(pf);
 
 		//update the help panel
 		if (app.getGuiManager().hasInputHelpPanel())
@@ -274,6 +286,13 @@ public class AlgebraInput extends  JPanel implements ActionListener, KeyListener
 			GeoElement[] geos;
 			try {
 				geos = app.getKernel().getAlgebraProcessor().processAlgebraCommandNoExceptionHandling( input, true, false, true );
+				
+				// need label if we type just eg
+				// lnx
+				if (geos.length == 1 && geos[0].label == null) {
+					geos[0].setLabel(geos[0].getDefaultLabel());
+				}
+				
 			} catch (Exception ee) {
 				inputField.showError(ee);
 				return;
