@@ -9,6 +9,7 @@ import geogebra.kernel.GeoImage;
 import geogebra.kernel.GeoList;
 import geogebra.kernel.GeoText;
 import geogebra.kernel.Kernel;
+import geogebra.main.Application;
 
 import java.awt.Point;
 import java.util.Iterator;
@@ -255,9 +256,23 @@ public class RelativeCopy {
 			text = value.getCommandDescription();
 		}
 
-		// enclose in quotes if we are copying a GeoText
+		// handle GeoText source value
 		if (value.isGeoText() && !((GeoText) value).isTextCommand()) {
-			text = "\"" + text + "\"";
+			// enclose text in quotes if we are copying an independent GeoText,
+			// e.g. "2+3"
+			if (value.isIndependent()) {
+				text = "\"" + text + "\"";
+			} else {
+
+				// check if 'text' parses to a GeoText
+				GeoText testGeoText = kernel.getAlgebraProcessor()
+						.evaluateToText(text, false, false);
+
+				// if it doesn't then force it to by adding +"" on the end
+				if (testGeoText == null) {
+					text = text + "+\"\"";
+				}
+			}
 		}
 
 		// for E1 = Polynomial[D1] we need value.getCommandDescription();
@@ -276,9 +291,9 @@ public class RelativeCopy {
 			}
 		}
 
-		// Application.debug("before:"+text);
+		Application.debug("before:"+text);
 		text = updateCellReferences(value, text, dx, dy);
-		// Application.debug("after:"+text);
+		Application.debug("after:"+text);
 
 		// condition to show object
 		GeoBoolean bool = value.getShowObjectCondition();
