@@ -1,13 +1,13 @@
 package geogebra.gui.view.spreadsheet.statdialog;
 
 import geogebra.euclidian.EuclidianView;
+import geogebra.gui.inputfield.AutoCompleteTextField;
 import geogebra.gui.inputfield.MyTextField;
 import geogebra.gui.util.GeoGebraIcon;
 import geogebra.kernel.AlgoHistogram;
 import geogebra.kernel.GeoElement;
 import geogebra.kernel.GeoList;
 import geogebra.main.Application;
-import geogebra.main.settings.EuclidianSettings;
 import geogebra.util.Validation;
 
 import java.awt.BorderLayout;
@@ -95,12 +95,11 @@ StatPanelInterface{
 	// geos
 	private GeoList regressionAnalysisList;
 	private ArrayList<GeoElement> plotGeoList;
-	
+
 	private GeoElement[] boxPlotTitles;
 	private GeoElement histogram, dotPlot, frequencyPolygon, normalCurve, 
-	scatterPlot, scatterPlotLine, residualPlot;
-;
-	
+	scatterPlot, scatterPlotLine, residualPlot, nqPlot, boxPlot;
+
 
 	// display panels 	
 	private JPanel displayCardPanel;
@@ -131,8 +130,8 @@ StatPanelInterface{
 	private JToolBar manualClassesPanel;
 	private JLabel lblStart;
 	private JLabel lblWidth;
-	private MyTextField fldStart;
-	private MyTextField fldWidth;
+	private AutoCompleteTextField fldStart;
+	private AutoCompleteTextField fldWidth;
 	private JLabel lblNumClasses;
 
 
@@ -151,7 +150,7 @@ StatPanelInterface{
 	private JLabel lblTitleX, lblTitleY;
 	private MyTextField fldTitleX, fldTitleY;
 	private FrequencyTable frequencyTable;
-
+	
 
 
 
@@ -228,12 +227,9 @@ StatPanelInterface{
 		}
 
 
-		// create display panels 
 
-		plotPanel = new PlotPanelEuclidianView(app.getKernel());
-		addPlotPanelExportMenu(plotPanel);
-		//plotPanel.setBorder(BorderFactory.createLineBorder(Color.GRAY));
-		//settings.plotPanel = plotPanel;
+		plotPanel = new PlotPanelEuclidianView(app.getKernel(), exportToEVAction);
+
 
 		plotPanelNorth = new JPanel();
 		plotPanelSouth = new JPanel();
@@ -436,10 +432,10 @@ StatPanelInterface{
 		fldNumClasses.setEditable(false);
 		fldNumClasses.setOpaque(true);
 		fldNumClasses.setColumns(2);
-		fldNumClasses.setHorizontalAlignment(JTextField.CENTER);
+		fldNumClasses.setHorizontalAlignment(SwingConstants.CENTER);
 		fldNumClasses.setBackground(Color.WHITE);
 
-		sliderNumClasses = new JSlider(JSlider.HORIZONTAL, 3, 20, numClasses);
+		sliderNumClasses = new JSlider(SwingConstants.HORIZONTAL, 3, 20, numClasses);
 		Dimension d = sliderNumClasses.getPreferredSize();
 		d.width = 80;
 		sliderNumClasses.setPreferredSize(d);
@@ -498,7 +494,7 @@ StatPanelInterface{
 		lblStart = new JLabel();
 		lblWidth = new JLabel();
 
-		fldStart = new MyTextField(app);
+		fldStart = new AutoCompleteTextField(4,app);
 		Dimension d = fldStart.getMaximumSize();
 		d.height = fldStart.getPreferredSize().height;
 		fldStart.setMaximumSize(d);
@@ -506,14 +502,14 @@ StatPanelInterface{
 		fldStart.setText("" + (int)settings.classStart);
 		fldStart.addFocusListener(this);
 
-		fldWidth = new MyTextField(app);
+		fldWidth = new AutoCompleteTextField(4,app);
 		fldWidth.setMaximumSize(d);
 		fldStart.setColumns(4);
 		fldWidth.setColumns(4);
 		fldWidth.addActionListener(this);
 		fldWidth.setText("" + (int)settings.classWidth);
 		fldWidth.addFocusListener(this);
-		
+
 		manualClassesPanel = new JToolBar();
 		manualClassesPanel.setFloatable(false);
 		manualClassesPanel.add(lblStart);
@@ -592,26 +588,18 @@ StatPanelInterface{
 	//              DISPLAY UPDATE
 	//==============================================
 
-	
+
 	public void updatePlot(boolean doCreate){
-		updatePlot(doCreate, true);
-	}
-	
-	public void updatePlot(boolean doCreate, boolean removeFromConstruction){
 
 		GeoList dataListSelected = statDialog.getStatDialogController().getDataSelected();
-		
-		statGeo.setRemoveFromConstruction(removeFromConstruction);
-		
-		
-		if(!removeFromConstruction){	
-			statDialog.getStatDialogController().setRegressionGeo();
-			
-		}
-	
-		
+
+
+		//if(!statGeo.removeFromConstruction()){	
+		//statDialog.getStatDialogController().setRegressionGeo();			
+		//}
+
+
 		GeoElement geo;
-		String underConstruction = "\\text{" + app.getPlain("NotAvailable") + "}";
 		if(hasControlPanel)
 			((CardLayout)controlCards.getLayout()).show(controlCards, "blankPanel");	
 
@@ -627,7 +615,7 @@ StatPanelInterface{
 			if(doCreate){
 				if(histogram != null)
 					histogram.remove();
-				histogram = statGeo.createHistogram( dataListSelected, numClasses, settings, false);
+				histogram = statGeo.createHistogram(dataListSelected, numClasses, settings, false);
 				plotGeoList.add(histogram);
 
 				if(frequencyPolygon != null)
@@ -663,9 +651,12 @@ StatPanelInterface{
 			break;	
 
 		case PLOT_BOXPLOT:
-			if(doCreate)
-				plotGeoList.add(statGeo.createBoxPlot( dataListSelected));
-
+			if(doCreate){
+				if(boxPlot != null)
+					boxPlot.remove();
+				boxPlot = statGeo.createBoxPlot( dataListSelected);
+				plotGeoList.add(boxPlot);
+			}
 			statGeo.getBoxPlotSettings( dataListSelected, settings);
 			plotPanel.updateSettings(settings);
 			((CardLayout)displayCardPanel.getLayout()).show(displayCardPanel, "plotPanel");
@@ -697,7 +688,10 @@ StatPanelInterface{
 
 		case PLOT_NORMALQUANTILE:
 			if(doCreate){
-				plotGeoList.add(statGeo.createNormalQuantilePlot( dataListSelected));
+				if(nqPlot != null)
+					nqPlot.remove();
+				nqPlot = statGeo.createNormalQuantilePlot( dataListSelected);
+				plotGeoList.add(nqPlot);
 			}
 			statGeo.updateNormalQuantilePlot(dataListSelected, settings);
 			plotPanel.updateSettings(settings);
@@ -775,7 +769,7 @@ StatPanelInterface{
 		}
 
 
-		if(doCreate && removeFromConstruction){
+		if(doCreate && statGeo.removeFromConstruction()){
 			for(GeoElement listGeo:plotGeoList){
 				// add the geo to our view and remove it from EV		
 				listGeo.addView(plotPanel.getViewID());
@@ -784,13 +778,13 @@ StatPanelInterface{
 				app.getEuclidianView().remove(listGeo);
 			}
 		}
-		
+
 		if(histogram != null){
 			histogram.setEuclidianVisible(settings.showHistogram);
-		histogram.updateRepaint();
+			histogram.updateRepaint();
 		}
-		
-		
+
+
 	}
 
 
@@ -835,7 +829,6 @@ StatPanelInterface{
 			optionsButton.setSelected(false);
 		}
 
-
 	}
 
 	private void doTextFieldActionPerformed(Object source){
@@ -858,7 +851,7 @@ StatPanelInterface{
 
 	public void focusGained(FocusEvent e) { }
 
-	
+
 
 	public void clearPlotGeoList(){
 		for(GeoElement geo : plotGeoList){
@@ -870,8 +863,8 @@ StatPanelInterface{
 		plotGeoList.clear();
 	}
 
-	
-	
+
+
 	public void removeGeos(){
 		clearPlotGeoList();
 	}
@@ -939,7 +932,7 @@ StatPanelInterface{
 	//           ComboBox Renderer with SEPARATOR
 	//============================================================
 
-	class MyRenderer extends JLabel implements ListCellRenderer {
+	private static class MyRenderer extends JLabel implements ListCellRenderer {
 
 		public static final String SEPARATOR = "SEPARATOR";
 		JSeparator separator;
@@ -947,7 +940,7 @@ StatPanelInterface{
 		public MyRenderer() {
 			setOpaque(true);
 			setBorder(new EmptyBorder(1, 1, 1, 1));
-			separator = new JSeparator(JSeparator.HORIZONTAL);
+			separator = new JSeparator(SwingConstants.HORIZONTAL);
 		}
 
 		public Component getListCellRendererComponent(JList list, Object value,
@@ -971,116 +964,147 @@ StatPanelInterface{
 
 
 
-	private void addPlotPanelExportMenu(PlotPanelEuclidianView plotPanel){
 
-		AbstractAction exportToEVAction = new AbstractAction(app
-				.getMenu("CopyToGraphics"), app
-				.getImageIcon("edit-copy.png")) {
-			private static final long serialVersionUID = 1L;
+	// **********************************************
+	//               Export
+	// **********************************************
 
-			public void actionPerformed(ActionEvent e) {
-				if(app.getShiftDown())
-					exportGeosToEV(Application.VIEW_EUCLIDIAN2);
-				else
-					exportGeosToEV(Application.VIEW_EUCLIDIAN);
+	/**
+	 * Action to export all GeoElements that are currently displayed in this
+	 * panel to a EuclidianView. The viewID for the target EuclidianView is
+	 * stored as a property with key "euclidianViewID".
+	 * 
+	 * This action is passed as a parameter to plotPanel where it is used in
+	 * the plotPanel context menu and the EuclidianView transfer handler
+	 * when the plot panel is dragged into an EV.
+	 */
+	AbstractAction exportToEVAction = new AbstractAction() {
+		private static final long serialVersionUID = 1L;
 
+		public void actionPerformed(ActionEvent event){
+			Integer euclidianViewID = (Integer) this.getValue("euclidianViewID");
+
+			// if null ID then use EV1 unless shift is down, then use EV2
+			if(euclidianViewID == null){
+				euclidianViewID = app.getShiftDown()? app.getEuclidianView2().getViewID() : app.getEuclidianView().getViewID();
 			}
-		};
 
-		plotPanel.appendActionList(exportToEVAction);
-	}
+			// do the export
+			exportGeosToEV(euclidianViewID);
+
+			// null out the ID property
+			this.putValue("euclidianViewID", null);
+		}
+	};
 
 
-	public void exportGeosToEV(int viewID){
+
+	/**
+	 * Exports all GeoElements that are currently displayed in this panel to a
+	 * target EuclidianView.
+	 * 
+	 * @param euclidianViewID
+	 *            viewID of the target EuclidianView
+	 */
+	public void exportGeosToEV(int euclidianViewID){
+
+		// TODO:
+		// in multivar mode create dynamic boxplots linked to separate lists
 
 		app.setWaitCursor();
-		ArrayList<GeoElement> newGeoList = new ArrayList<GeoElement>();
-		String expr;
+		//app.storeUndoInfo();	
+		GeoElement regressionCopy = null;
+		EuclidianView targetEV  = (EuclidianView) app.getView(euclidianViewID);
 
 		try {
-			app.storeUndoInfo();
 
-			// prepare the data list to display in the EV (e.g. set labels, auxiliary = false)
-			GeoList dataListSelected = statDialog.getStatDialogController().getDataSelected();
-			prepareGeoForEV(dataListSelected, viewID);
-			
+			// =================================================================
+			// Step 1:
+			// Update the plot geos with the reomoveFromConstruction
+			// flag set to false. This ensures that the display geos have been
+			// put in the construction list and will be saved to xml.
+			// =================================================================
 
-			// update the plot to get a new set of geos that exist in the construction
-			updatePlot(true, false);
+			statGeo.setRemoveFromConstruction(false);
+			updatePlot(true);
+
+			// =================================================================
+			// Step 2:
+			// Prepare the geos for display in the currently active EV
+			// (set labels, make visible, etc). 
+			// =================================================================
 
 			// remove the histogram from the plot geo list if it is not showing
-			if(histogram != null && settings.showHistogram == false){
+			if (histogram != null && settings.showHistogram == false) {
 				plotGeoList.remove(histogram);
 				histogram.remove();
 				histogram = null;
 			}
 
-			// prepare the new geos to display in the EV (e.g. set labels, auxiliary = false)
-			for(GeoElement geo: plotGeoList){
-				prepareGeoForEV(geo, viewID);
-			}
-			
-			GeoElement regressionCopy = null;
-			if(statDialog.getMode() == StatDialog.MODE_REGRESSION 
-					&& statDialog.getRegressionMode() != StatDialog.REG_NONE)
-			{
-				regressionCopy = (GeoElement)statGeo.createRegressionPlot((GeoList) dataListSelected,
-						statDialog.getRegressionMode(), statDialog.getRegressionOrder(), false);
-				prepareGeoForEV(regressionCopy, viewID);
+			// prepare all display geos to appear in the EV
+			for (GeoElement geo : plotGeoList) {
+				prepareGeoForEV(geo, euclidianViewID);
 			}
 
-			// set the window dimensions of the target EV to match the plotPanel dimensions
-			EuclidianView ev  = (EuclidianView) app.getView(viewID);
-			ev.setRealWorldCoordSystem(settings.xMin, settings.xMax, settings.yMin, settings.yMax);
-			ev.setAutomaticAxesNumberingDistance(settings.xAxesIntervalAuto, 0);
-			ev.setAutomaticAxesNumberingDistance(settings.yAxesIntervalAuto, 1);
-			if(!settings.xAxesIntervalAuto){
-				ev.setAxesNumberingDistance(settings.xAxesInterval, 0);
+			// the regression geo is maintained by StatDialog, so we create a
+			// copy and prepare this for the EV
+			if (statDialog.getMode() == StatDialog.MODE_REGRESSION
+					&& statDialog.getRegressionMode() != StatDialog.REG_NONE) {
+				
+				regressionCopy = statGeo.createRegressionPlot(
+						(GeoList) scatterPlot, statDialog.getRegressionMode(),
+						statDialog.getRegressionOrder(), false);
+				prepareGeoForEV(regressionCopy, euclidianViewID);
 			}
-			if(!settings.yAxesIntervalAuto){
-				ev.setAxesNumberingDistance(settings.yAxesInterval, 1);
-			}
-			ev.updateBackground();			
-						
 
-			// null our display geos and clear the plotGeoList to unlink the new geos
+			// =================================================================
+			// Step 3:
+			// Adjust the target EV window to match the plotPanel dimensions
+			// =================================================================
+
+			targetEV.setRealWorldCoordSystem(settings.xMin, settings.xMax,
+					settings.yMin, settings.yMax);
+			targetEV.setAutomaticAxesNumberingDistance(
+					settings.xAxesIntervalAuto, 0);
+			targetEV.setAutomaticAxesNumberingDistance(
+					settings.yAxesIntervalAuto, 1);
+			if (!settings.xAxesIntervalAuto) {
+				targetEV.setAxesNumberingDistance(settings.xAxesInterval, 0);
+			}
+			if (!settings.yAxesIntervalAuto) {
+				targetEV.setAxesNumberingDistance(settings.yAxesInterval, 1);
+			}
+			targetEV.updateBackground();
+
+			// =================================================================
+			// Step 4:
+			// Dereference the geos from fields in this class and the StatDialog
+			// =================================================================
+
+			// null the display geos
 			boxPlotTitles = null;
 			histogram = null;
 			dotPlot = null;
 			frequencyPolygon = null;
-			normalCurve = null; 
+			normalCurve = null;
 			scatterPlotLine = null;
-			
-			if(scatterPlot != null){
-				scatterPlot.remove(); // dataListSelected already gives the scatterplot 
-				scatterPlot = null;
-			}
-			
-			if(residualPlot != null){
-				residualPlot = null;
-				regressionCopy.remove();
-				dataListSelected.setEuclidianVisible(false); // hide the dataListSelected scatterplot 
-				dataListSelected.updateRepaint();
-				
-			}
-			
-			
-			//TODO: in multivar mode create dynamic boxplots linked to separate lists
-			if(statDialog.getMode() == StatDialog.MODE_MULTIVAR){
-				dataListSelected.remove();
-			}
-			
-			
-			plotGeoList.clear();
+			scatterPlot = null;
+			nqPlot = null;
+			boxPlot = null;
 
-			
 			statDialog.getStatDialogController().removeRegressionGeo();
 			statDialog.getStatDialogController().removeDataListSelected();
+			plotGeoList.clear();
+		
+			// =================================================================
+			// Step 5:
+			// Reload the data and create new display geos that are not
+			// in the construction list.
+			// =================================================================
+		
 			statDialog.getStatDialogController().loadDataLists();
-			
-			//update the plot in removeFromConstruction mode to get a new set of geos for our plot
-			updatePlot(true, true);
-
+			statGeo.setRemoveFromConstruction(true);
+			updatePlot(true);
 
 		} catch (Exception e) {
 			e.printStackTrace();
@@ -1088,20 +1112,29 @@ StatPanelInterface{
 		}
 
 		app.setDefaultCursor();
+		app.storeUndoInfo();
 	}
 
-	
-	private void prepareGeoForEV(GeoElement geo, int viewID){
+
+	/**
+	 * Prepares the specified GeoElement for visibility in a target
+	 * EuclidianView.
+	 * 
+	 * @param geo
+	 * @param euclidianViewID
+	 *            viewID of the target EuclidianView
+	 */
+	private static void prepareGeoForEV(GeoElement geo, int euclidianViewID){
 
 		geo.setLabel(null);
 		geo.setEuclidianVisible(true);
 		geo.setAuxiliaryObject(false);
-		if(viewID == Application.VIEW_EUCLIDIAN){
+		if(euclidianViewID == Application.VIEW_EUCLIDIAN){
 			geo.addView(Application.VIEW_EUCLIDIAN);
 			geo.removeView(Application.VIEW_EUCLIDIAN2);
 			geo.update();
 		}
-		if(viewID == Application.VIEW_EUCLIDIAN2){
+		if(euclidianViewID == Application.VIEW_EUCLIDIAN2){
 			geo.addView(Application.VIEW_EUCLIDIAN2);
 			geo.removeView(Application.VIEW_EUCLIDIAN);
 			geo.update();
