@@ -72,13 +72,13 @@ SpecialNumberFormatInterface {
 	public static final Color NQPLOT_COLOR =  GeoGebraColorConstants.GRAY5;    
 	public static final Color REGRESSION_COLOR = Color.RED;   
 	public static final Color OVERLAY_COLOR = GeoGebraColorConstants.DARKBLUE;    
-	
+
 	public static final float opacityBarChart = 0.3f; 
 	public static final int thicknessCurve = 4;
 	public static final int thicknessBarChart = 3;
-	
-	
-	
+
+
+
 
 	// regression types
 	public static final int REG_NONE = 0;
@@ -191,16 +191,6 @@ SpecialNumberFormatInterface {
 		statisticsPanel.setBorder(BorderFactory.createEmptyBorder(4, 2, 2, 2));
 
 
-		// Create DataPanel to display the current data set(s) and allow
-		// temporary editing. 
-		if(mode != MODE_MULTIVAR){
-			dataPanel = new DataPanel(app, this, sdc.getDataAll(), mode);
-			//dataPanel.setBorder(BorderFactory.createLineBorder(Color.GRAY));
-			dataPanel.setBorder(BorderFactory.createEmptyBorder(2, 2, 2, 2));
-		}
-
-
-
 		// Init the GUI and attach this view to the kernel
 
 		initGUI();
@@ -215,7 +205,18 @@ SpecialNumberFormatInterface {
 	}
 
 
+	// Create DataPanel to display the current data set(s) and allow 
+	// temporary editing. 
+	protected DataPanel getDataPanel(){ 
 
+		if(dataPanel == null && mode != MODE_MULTIVAR){ 
+			dataPanel = new DataPanel(app, this); 
+			dataPanel.setBorder(BorderFactory.createEmptyBorder(2, 2, 2, 2)); 
+		} 
+
+		return dataPanel; 
+
+	} 
 
 	//=================================================
 	//       GUI
@@ -410,7 +411,7 @@ SpecialNumberFormatInterface {
 	public int getPrintDecimals(){
 		return nf.getPrintDecimals();
 	}
-	
+
 	public int getPrintFigures(){
 		return nf.getPrintFigures();
 	}
@@ -821,19 +822,19 @@ SpecialNumberFormatInterface {
 	public int getViewID() {
 		return Application.VIEW_NONE;
 	}
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
-	
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 }
