@@ -60,9 +60,6 @@ public class MyXMLio {
 	// All xml output is zipped. The created zip archive contains
 	// an entry named XML_FILE for the construction
 	final private static String XML_FILE = "geogebra.xml";
-	// Added for Intergeo File Format (Yves Kreis) -->
-	final private static String I2G_FILE = "construction/intergeo.xml";
-	// <-- Added for Intergeo File Format (Yves Kreis)
 
 	// All xml output is zipped. The created zip archive contains
 	// an entry named XML_FILE_MACRO for the macros
@@ -74,35 +71,21 @@ public class MyXMLio {
 	// All xml output is zipped. The created zip archive *may* contain
 	// an entry named XML_FILE_THUMBNAIL for the construction
 	final private static String XML_FILE_THUMBNAIL = "geogebra_thumbnail.png";
-	// Added for Intergeo File Format (Yves Kreis) -->
-	final private static String I2G_FILE_THUMBNAIL = "construction/preview.png";
-	// <-- Added for Intergeo File Format (Yves Kreis)
 	final public static double THUMBNAIL_PIXELS_X = 200.0; // max no of
 															// horizontal pixels
 	final public static double THUMBNAIL_PIXELS_Y = 200.0; // max no of
 															// vertical pixels
 
-	// Added for Intergeo File Format (Yves Kreis) -->
-	final private static String I2G_IMAGES = "resources/images/";
-	final private static String I2G_PRIVATE = "private/org.geogebra/";
-	final private static String I2G_PRIVATE_IMAGES = "private/org.geogebra/images/";
-	// <-- Added for Intergeo File Format (Yves Kreis)
-
 	// Use the default (non-validating) parser
 	// private static XMLReaderFactory factory;
 
 	private Application app;
 	private Kernel kernel;
-	// Modified for Intergeo File Format (Yves Kreis) -->
 	// private MyXMLHandler handler;
-	private DocHandler handler, ggbDocHandler, i2gDocHandler;
-	// <-- Modified for Intergeo File Format (Yves Kreis)
+	private DocHandler handler, ggbDocHandler;
 	private QDParser xmlParser;
-	// Added for Intergeo File Format (Yves Kreis) -->
 	private Construction cons;
 
-	// <-- Added for Intergeo File Format (Yves Kreis)
-
 	public MyXMLio(Kernel kernel, Construction cons) {
 		this.kernel = kernel;
 		this.cons = cons;	
@@ -119,13 +102,6 @@ public class MyXMLio {
 			ggbDocHandler = kernel.newMyXMLHandler(cons);
 		return ggbDocHandler;
 	}
-	
-	private DocHandler getI2GHandler() {
-		if (i2gDocHandler == null)
-			i2gDocHandler = new MyI2GHandler(kernel, cons);		
-		return i2gDocHandler;
-	}
-
 
 	/**
 	 * Reads zipped file from input stream that includes the construction saved
@@ -175,20 +151,13 @@ public class MyXMLio {
 				break;
 
 			String name = entry.getName();
-			if (name.equals(XML_FILE) || name.equals(I2G_PRIVATE + XML_FILE)) {
+			if (name.equals(XML_FILE)) {
 				// load xml file into memory first
 				xmlFileBuffer = Util.loadIntoMemory(zip);
 				xmlFound = true;
 				ggbHandler = true;
-				// Added for Intergeo File Format (Yves Kreis) -->
 				handler = getGGBHandler();
-			} else if (!ggbHandler && name.equals(I2G_FILE)) {
-				// load i2g file into memory first
-				xmlFileBuffer = Util.loadIntoMemory(zip);
-				xmlFound = true;
-				handler = getI2GHandler();
-				// <-- Added for Intergeo File Format (Yves Kreis)
-			} else if (name.equals(XML_FILE_MACRO) || name.equals(I2G_PRIVATE + XML_FILE_MACRO)) {
+			} else if (name.equals(XML_FILE_MACRO)) {
 				// load macro xml file into memory first
 				macroXmlFileBuffer = Util.loadIntoMemory(zip);
 				macroXMLfound = true;
@@ -388,17 +357,9 @@ public class MyXMLio {
 		// create file
 		FileOutputStream f = new FileOutputStream(file);
 		BufferedOutputStream b = new BufferedOutputStream(f);
-		// Modified for Intergeo File Format (Yves Kreis) -->
-		// writeGeoGebraFile(b);
-		if (Application.getExtension(file)
-				.equals(Application.FILE_EXT_INTERGEO)) {
-			// File Extension for Intergeo: I2G
-			writeIntergeoFile(b, true);
-		} else {
-			// File Extension for GeoGebra: GGB or GGT
-			writeGeoGebraFile(b, true);
-		}
-		// <-- Modified for Intergeo File Format (Yves Kreis)
+
+		writeGeoGebraFile(b, true);
+		
 		b.close();
 		f.close();
 	}
@@ -419,12 +380,10 @@ public class MyXMLio {
 			// write construction images
 			writeConstructionImages(kernel.getConstruction(), zip);
 	
-			// Modified for Intergeo File Format (Yves Kreis) -->
 			// write construction thumbnails
 			// writeThumbnail(kernel.getConstruction(), zip);
 			if (includeThumbail)
 				writeThumbnail(kernel.getConstruction(), zip, XML_FILE_THUMBNAIL);
-			// <-- Modified for Intergeo File Format (Yves Kreis)
 	
 			// save macros
 			if (kernel.hasMacros()) {
@@ -464,70 +423,6 @@ public class MyXMLio {
 		}
 	}
 
-	/**
-	 * Creates a zipped file containing the construction saved in xml and i2g
-	 * format plus all external images. Intergeo File Format (Yves Kreis)
-	 */
-	public void writeIntergeoFile(OutputStream os, boolean includeThumbail) throws IOException {
-		boolean isSaving = kernel.isSaving();
-		kernel.setSaving(true);
-		
-		try {
-			// zip stream
-			ZipOutputStream zip = new ZipOutputStream(os);
-			OutputStreamWriter osw = new OutputStreamWriter(zip, "UTF8");
-	
-			// write I2G file for construction
-			zip.putNextEntry(new ZipEntry(I2G_FILE));
-			osw.write(getFullI2G());
-			osw.flush();
-			zip.closeEntry();
-	
-			// write construction thumbnails
-			if (includeThumbail)
-				writeThumbnail(kernel.getConstruction(), zip, I2G_FILE_THUMBNAIL);
-	
-			// write construction images
-			writeConstructionImages(kernel.getConstruction(), zip, I2G_IMAGES);
-	
-			// save macros
-			if (kernel.hasMacros()) {
-				// get all registered macros from kernel
-				ArrayList macros = kernel.getAllMacros();
-	
-				// write all images used by macros
-				writeMacroImages(macros, zip, I2G_PRIVATE_IMAGES);
-	
-				// write all macros to one special XML file in zip
-				zip.putNextEntry(new ZipEntry(I2G_PRIVATE + XML_FILE_MACRO));
-				osw.write(getFullMacroXML(macros));
-				osw.flush();
-				zip.closeEntry();
-			}
-	
-			// write library JavaScript to one special file in zip
-			zip.putNextEntry(new ZipEntry(I2G_PRIVATE + JAVASCRIPT_FILE));
-			osw.write(kernel.getLibraryJavaScript());
-			osw.flush();
-			zip.closeEntry();
-	
-			// write XML file for construction
-			zip.putNextEntry(new ZipEntry(I2G_PRIVATE + XML_FILE));
-			osw.write(getFullXML());
-			osw.flush();
-			zip.closeEntry();
-	
-			osw.close();
-			zip.close();
-		} 
-		catch (IOException e) {
-			throw e;
-		}
-		finally {
-			kernel.setSaving(isSaving);
-		}
-	}
-
 	/**
 	 * Creates a zipped file containing the given macros in xml format plus all
 	 * their external images (e.g. icons).
@@ -570,7 +465,6 @@ public class MyXMLio {
 	/**
 	 * Writes all images used in construction to zip.
 	 */
-	// Modified for Intergeo File Format (Yves Kreis) -->
 	private void writeConstructionImages(Construction cons, ZipOutputStream zip)
 			throws IOException {
 		writeConstructionImages(cons, zip, "");
@@ -578,9 +472,6 @@ public class MyXMLio {
 
 	private void writeConstructionImages(Construction cons,
 			ZipOutputStream zip, String filePath) throws IOException {
-		// <-- Modified for Intergeo File Format (Yves Kreis)
-		// save all GeoImage images
-		//TreeSet images = cons.getGeoSetLabelOrder(GeoElement.GEO_CLASS_IMAGE);
 		TreeSet geos = cons.getGeoSetLabelOrder();
 		if (geos == null)
 			return;
@@ -602,12 +493,10 @@ public class MyXMLio {
 	/**
 	 * Writes thumbnail to zip. Michael Borcherds 2008-04-18
 	 */
-	// Modified for Intergeo File Format (Yves Kreis) -->
 	// private void writeThumbnail(Construction cons, ZipOutputStream zip)
 	// throws IOException {
 	private void writeThumbnail(Construction cons, ZipOutputStream zip,
 			String fileName) throws IOException {
-		// <-- Modified for Intergeo File Format (Yves Kreis)
 
 		EuclidianView ev = app.getEuclidianView();
 
@@ -622,10 +511,7 @@ public class MyXMLio {
 			//BufferedImage img = app.getExportImage(exportScale);
 			BufferedImage img = app.getExportImage(THUMBNAIL_PIXELS_X,THUMBNAIL_PIXELS_Y);
 			if (img != null)
-				// Modified for Intergeo File Format (Yves Kreis) -->
-				// writeImageToZip(zip, XML_FILE_THUMBNAIL, img);
 				writeImageToZip(zip, fileName, img);
-			// <-- Modified for Intergeo File Format (Yves Kreis)
 		} catch (Exception e) { } // catch error if size is zero
 
 	}
@@ -633,7 +519,6 @@ public class MyXMLio {
 	/**
 	 * Writes all images used in the given macros to zip.
 	 */
-	// Modified for Intergeo File Format (Yves Kreis) -->
 	private void writeMacroImages(ArrayList macros, ZipOutputStream zip)
 			throws IOException {
 		writeMacroImages(macros, zip, "");
@@ -641,26 +526,19 @@ public class MyXMLio {
 
 	private void writeMacroImages(ArrayList macros, ZipOutputStream zip,
 			String filePath) throws IOException {
-		// <-- Modified for Intergeo File Format (Yves Kreis)
 		if (macros == null)
 			return;
 
 		for (int i = 0; i < macros.size(); i++) {
 			// save all images in macro construction
 			Macro macro = (Macro) macros.get(i);
-			// Modified for Intergeo File Format (Yves Kreis) -->
-			// writeConstructionImages(macro.getMacroConstruction(), zip);
 			writeConstructionImages(macro.getMacroConstruction(), zip, filePath);
-			// <-- Modified for Intergeo File Format (Yves Kreis)
 
 			// save macro icon
 			String fileName = macro.getIconFileName();
 			BufferedImage img = app.getExternalImage(fileName);
 			if (img != null)
-				// Modified for Intergeo File Format (Yves Kreis) -->
-				// writeImageToZip(zip, fileName, img);
 				writeImageToZip(zip, filePath + fileName, img);
-			// <-- Modified for Intergeo File Format (Yves Kreis)
 		}
 	}
 
@@ -775,38 +653,6 @@ public class MyXMLio {
 		return sb.toString();
 	}
 
-	/**
-	 * Returns I2G representation of construction. Intergeo File Format.
-	 * (Yves Kreis)
-	 */
-	public String getFullI2G() {
-		StringBuilder sb = new StringBuilder();
-		//addXMLHeader(sb);
-
-		sb.append("<!--\n\tIntergeo File Format Version "
-				+ GeoGebra.I2G_FILE_FORMAT + "\n\twritten by "
-				+ app.getPlain("ApplicationName") + " "
-				+ GeoGebra.VERSION_STRING + " (" + GeoGebra.BUILD_DATE
-				+ ")\n-->\n");
-
-		sb.append("<construction>\n");
-
-		// save construction
-		cons.getConstructionI2G(sb, Construction.CONSTRUCTION);
-
-		StringBuilder display = new StringBuilder();
-		cons.getConstructionI2G(display, Construction.DISPLAY);
-		if (!display.toString().equals("")) {
-			sb.append("\t<display>\n");
-			sb.append(display.toString());
-			sb.append("\t</display>\n");
-		}
-
-		sb.append("</construction>\n");
-
-		return sb.toString();
-	}
-
 	/**
 	 * Returns XML representation of all settings WITHOUT construction.
 	 */
