@@ -16,6 +16,8 @@ import geogebra.euclidian.EuclidianView;
 import geogebra.io.MyXMLio;
 import geogebra.kernel.arithmetic.ExpressionNode;
 import geogebra.kernel.arithmetic.ExpressionNodeConstants;
+import geogebra.kernel.arithmetic.Function;
+import geogebra.kernel.arithmetic.FunctionVariable;
 import geogebra.kernel.arithmetic.NumberValue;
 import geogebra.kernel.cas.AlgoDependentCasCell;
 import geogebra.kernel.kernelND.GeoPointND;
@@ -27,7 +29,6 @@ import geogebra.util.Util;
 import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.Iterator;
 import java.util.TreeSet;
 import java.util.regex.Matcher;
@@ -46,13 +47,6 @@ import java.util.regex.Matcher;
  */
 public class Construction {
 
-	/** Added for Intergeo File Format (Yves Kreis) -->
-	 writes the <elements> and the <constraints> part */
-	public static final int CONSTRUCTION = 0;
-	/** Added for Intergeo File Format (Yves Kreis) 
-	 * writes the <display> part with the <display> tag */
-	public static final int DISPLAY = 1;
-	
 	private String title, author, date;
 	// text for dynamic worksheets: 0 .. above, 1 .. below
 	private String[] worksheetText = new String[2];
@@ -906,7 +900,7 @@ public class Construction {
 		
 		if (updateAlgos != null) {
 			Application app = kernel.getApplication();
-			if (app.useFullGui())
+			if (app.useFullGui() && app.getGuiManager() != null)
 				app.getGuiManager().updateConstructionProtocol();
 		}
 
@@ -1209,7 +1203,7 @@ public class Construction {
 	 * @param label label to be looked for
 	 * @return may return null
 	 */
-	GeoElement lookupLabel(String label) {
+	public GeoElement lookupLabel(String label) {
 		return lookupLabel(label, false);
 	}
 	
@@ -1416,150 +1410,159 @@ public class Construction {
 				}
 			}
 
+		} else if (label.length() == 1) {
+			if (label.equals("O")) {
+				
+				createdGeo = new GeoPoint(this, 0d, 0d, 1d);
+				label = "O";
+				auxilliary = true;
+				fix = true;
+			} 
 		} else if (label.length() == 3) {
 			if (label.equals("lnx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("ln(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				
+				createdGeo = createFunction(ExpressionNode.LOG);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} 
 		} else if (label.length() == 4) {
 			if (label.equals("sinx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("sin(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.SIN);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("cosx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("cos(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.COS);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("tanx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("tan(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.TAN);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("secx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("sec(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.SEC);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("cscx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("csc(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.CSC);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("cotx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("cot(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.COT);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("logx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("log(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.LOG);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			}
 		} else if (label.length() == 5) {
 			if (label.equals("sinhx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("sinh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.SINH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("coshx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("cosh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.COSH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("tanhx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("tanh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.TANH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("sechx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("sech(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.SECH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("cothx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("coth(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.COTH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("acosx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("acos(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ARCCOS);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("asinx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("asin(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ARCSIN);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("atanx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("atan(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ARCTAN);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			}
 		} else if (label.length() == 6) {
 			if (label.equals("cosecx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("cosec(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.CSC);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("arcosx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("acos(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ARCCOS);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("asinhx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("asinh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ASINH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("acoshx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("acosh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ACOSH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("atanhx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("atanh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ATANH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			}
 		} else if (label.length() == 7) {
 			if (label.equals("arccosx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("acos(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ARCCOS);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("arcsinx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("asin(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ARCSIN);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("arctanx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("atan(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ARCTAN);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} 
 		} else if (label.length() == 8) {
 			if (label.equals("arccoshx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("acosh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ACOSH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("arcsinhx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("asinh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ASINH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} else if (label.equals("arctanhx")) {
-				createdGeo = kernel.getAlgebraProcessor().evaluateToFunction("atanh(x)",true); 
-				label=createdGeo.getDefaultLabel();
+				createdGeo = createFunction(ExpressionNode.ATANH);
+				label = null;
 				auxilliary = false;
 				fix = false;
 			} 
@@ -1576,7 +1579,9 @@ public class Construction {
 			//setSuppressLabelCreation(false);
 			
 			createdGeo.setAuxiliaryObject(auxilliary);
-			createdGeo.setLabel(label);
+			if (label != null) {
+				createdGeo.setLabel(label);
+			}
 			createdGeo.setFixed(fix);
 			
 			// revert to previous label creation state
@@ -1606,6 +1611,13 @@ public class Construction {
 		return createdGeo;
 	}
 	
+	private GeoFunction createFunction(int op) {
+		FunctionVariable x = new FunctionVariable(kernel);
+		ExpressionNode en = new ExpressionNode(kernel, x, op, null);
+		Function fun = new Function(en, x);
+		return new GeoFunction(this, fun);
+	}
+
 	/**
 	 * Returns whether the specified label will automatically create a GeoElement
 	 * when autoCreateGeoElement() is called with it.
@@ -2283,76 +2295,6 @@ public class Construction {
 		}
 	}	
 
-	/*
-	 * XML output
-	 */
-
-//	/**
-//	 * Returns this construction in XML format. GeoGebra File Format.
-//	 */
-//	public String getXML(boolean includeConstruction) {
-//		StringBuilder sb = new StringBuilder();
-//
-//		// kernel settings
-//		sb.append("<kernel>\n");
-//
-//		// continuity: true or false, since V3.0
-//		sb.append("\t<continuous val=\"");
-//		sb.append(kernel.isContinuous());
-//		sb.append("\"/>\n");
-//		
-//		if (kernel.useSignificantFigures) {
-//			// significant figures
-//			sb.append("\t<significantfigures val=\"");
-//			sb.append(kernel.getPrintFigures());
-//			sb.append("\"/>\n");			
-//		}
-//		else
-//		{
-//			// decimal places
-//			sb.append("\t<decimals val=\"");
-//			sb.append(kernel.getPrintDecimals());
-//			sb.append("\"/>\n");
-//		}
-//		
-//		// angle unit
-//		sb.append("\t<angleUnit val=\"");
-//		sb.append(angleUnit == Kernel.ANGLE_RADIANT ? "radiant" : "degree");
-//		sb.append("\"/>\n");
-//
-//		// coord style
-//		sb.append("\t<coordStyle val=\"");
-//		sb.append(kernel.getCoordStyle());
-//		sb.append("\"/>\n");
-//		
-//		// animation
-//		if (kernel.isAnimationRunning()) {
-//			sb.append("\t<startAnimation val=\"");
-//			sb.append(kernel.isAnimationRunning());
-//			sb.append("\"/>\n");
-//		}
-//
-//		sb.append("</kernel>\n");
-//
-//		// construction XML
-//		if (includeConstruction)
-//			sb.append(getConstructionXML());
-//
-//		return sb.toString();
-//	}
-
-//	/**
-//	 * Returns this construction in I2G format. Intergeo File Format.
-//	 * (Yves Kreis)
-//	 */
-//	public String getI2G(int mode) {
-//		StringBuilder sb = new StringBuilder();
-//
-//		// construction I2G
-//		sb.append(getConstructionI2G(mode));
-//
-//		return sb.toString();
-//	}
 
 	/**
 	 * Returns this construction in XML format. GeoGebra File Format.
@@ -2452,59 +2394,6 @@ public class Construction {
 
 	}    	
 	
-	
-	
-	
-	/**
-	 * Returns this construction in I2G format. Intergeo File Format.
-	 * (Yves Kreis)
-	 * @param sb String builder to which the XML is appended
-	 * @param mode output mode, either CONSTRUCTION (0) or DISPLAY (1)
-	 */
-	public void getConstructionI2G(StringBuilder sb, int mode) {
-		
-		// change kernel settings temporarily
-		int oldCoordStlye = kernel.getCoordStyle();
-		int oldPrintForm = kernel.getCASPrintForm();
-        boolean oldValue = kernel.isPrintLocalizedCommandNames();
-		kernel.setCoordStyle(Kernel.COORD_STYLE_DEFAULT);
-		kernel.setCASPrintForm(ExpressionNode.STRING_TYPE_GEOGEBRA_XML);
-        kernel.setPrintLocalizedCommandNames(false); 
-
-		try {
-			ConstructionElement ce;
-			int size = ceList.size();
-
-			if (mode == CONSTRUCTION) {
-				sb.append("\t<elements>\n");
-				for (int i = 0; i < size; ++i) {
-					ce = (ConstructionElement) ceList.get(i);
-					ce.getI2G(sb, ConstructionElement.ELEMENTS);
-				}
-				sb.append("\t</elements>\n");
-
-				sb.append("\t<constraints>\n");
-				for (int i = 0; i < size; ++i) {
-					ce = (ConstructionElement) ceList.get(i);
-					ce.getI2G(sb, ConstructionElement.CONSTRAINTS);
-				}
-				sb.append("\t</constraints>\n");
-			} else if (mode == DISPLAY) {
-				for (int i = 0; i < size; ++i) {
-					ce = (ConstructionElement) ceList.get(i);
-					ce.getI2G(sb, ConstructionElement.DISPLAY);
-				}
-			}
-		} catch (Exception e) {
-			e.printStackTrace();
-		}
-
-		kernel.setCoordStyle(oldCoordStlye);
-		kernel.setCASPrintForm(oldPrintForm);
-		kernel.setPrintLocalizedCommandNames(oldValue);                          
-		
-	}
-
 	/**
 	 * Returns undo xml string of this construction.
 	 * @return StringBuilder with xml  of this construction.
