@@ -731,4 +731,14 @@ implements FunctionalNVar, CasEvaluableFunction, Region, Transformable, Translat
 		public boolean isGeoFunctionNVar(){
 			return true;
 		}
+		
+		protected void getXMLtags(StringBuilder sb) {
+			super.getXMLtags(sb);
+			
+			// needed for inequalities
+			if (isInequality()) {
+				getLineStyleXML(sb);
+			}
+			
+		}
 }
