@@ -45,7 +45,7 @@ import javax.swing.text.Document;
  * @author Markus
  * @version
  */
-public class ExpressionNode extends ValidExpression implements ReplaceableValue, ExpressionNodeConstants {
+public class ExpressionNode extends ValidExpression implements ReplaceableValue, ExpressionNodeConstants, ReplaceChildrenByValues {
 
 	public Application app;
 	public Kernel kernel;
@@ -199,6 +199,9 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 		if (ev.isExpressionNode()) {
 			ExpressionNode en = (ExpressionNode) ev;
 			ret = en.getCopy(kernel);
+		} else if (ev instanceof MyList) { 
+			MyList en = (MyList) ev; 
+			ret = en.getCopy(kernel); 
 		}
 		// deep copy
 		else if (ev.isPolynomialInstance() || ev.isConstant() || (ev instanceof Command)) {
@@ -831,6 +834,8 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 		// handle command arguments
 		else if (left instanceof Command) {
 			((Command) left).replaceChildrenByValues(geo);
+		} else if (left instanceof ReplaceChildrenByValues) { 
+			((ReplaceChildrenByValues) left).replaceChildrenByValues(geo);
 		}
 
 		// right tree
@@ -846,6 +851,8 @@ public class ExpressionNode extends ValidExpression implements ReplaceableValue,
 			// handle command arguments
 			else if (right instanceof Command) {
 				((Command) right).replaceChildrenByValues(geo);
+			} else if (right instanceof ReplaceChildrenByValues) { 
+				((ReplaceChildrenByValues) right).replaceChildrenByValues(geo); 
 			}
 		}
 	}
