@@ -14,6 +14,7 @@ package geogebra.kernel.arithmetic;
 
 import geogebra.kernel.CasEvaluableFunction;
 import geogebra.kernel.GeoElement;
+import geogebra.kernel.GeoFunction;
 import geogebra.kernel.GeoFunctionNVar;
 import geogebra.kernel.GeoPoint;
 import geogebra.kernel.Kernel;
@@ -441,8 +442,11 @@ public class FunctionNVar extends ValidExpression implements ReplaceableValue,
 		} else if (ev.isNumberValue()) {
 			isBooleanFunction = false;		
 		} else if (ev instanceof FunctionNVar){
-				expression = ((FunctionNVar)ev).getExpression();
-				fVars = ((FunctionNVar)ev).getFunctionVariables();	
+			expression = ((FunctionNVar)ev).getExpression();
+			fVars = ((FunctionNVar)ev).getFunctionVariables();	
+		} else if (ev instanceof GeoFunction){
+			expression = ((GeoFunction)ev).getFunctionExpression();
+			fVars =  ((GeoFunction)ev).getFunction().getFunctionVariables();
 		}else{
 			Application.debug("InvalidFunction:" + expression.toString() + " "
 					+ ev.toString() + ev.getClass().getName());
@@ -836,15 +840,13 @@ public class FunctionNVar extends ValidExpression implements ReplaceableValue,
 			return initIneqs(leftTree, functional, tree,!negate);
 		}else if (op == ExpressionNode.FUNCTION_NVAR) {
 			FunctionalNVar nv = (FunctionalNVar)leftTree.getLeft();
-			IneqTree otherTree = nv.getIneqs();
-			if(otherTree == null || otherTree.getSize()==0){
-				return false;
-			}
-			tree.left = otherTree.left;
-			tree.right = otherTree.right;
-			tree.operation =otherTree.operation;
-			tree.ineq =otherTree.ineq;
-			return true;
+			ExpressionNode subExpr = nv.getFunction().getExpression().getCopy(kernel);
+			FunctionVariable[] subVars = nv.getFunction().getFunctionVariables();
+			for(int i=0;i<subVars.length;i++)
+				subExpr.replace(subVars[i], 
+						((MyList)rightTree.getLeft()).getListElement(i));
+			return initIneqs(subExpr,functional,tree,negate);
+
 		} 
 		else
 			return false;
