@@ -37,7 +37,6 @@ import geogebra.kernel.arithmetic.Polynomial;
 import geogebra.kernel.arithmetic.TextValue;
 import geogebra.kernel.arithmetic.ValidExpression;
 import geogebra.kernel.arithmetic.VectorValue;
-import geogebra.kernel.cas.AlgoDependentCasCell;
 import geogebra.kernel.implicit.GeoImplicitPoly;
 import geogebra.kernel.kernelND.GeoPointND;
 import geogebra.kernel.parser.ParseException;
@@ -47,7 +46,6 @@ import geogebra.main.MyError;
 
 import java.util.ArrayList;
 import java.util.Set;
-import java.util.TreeSet;
 
 public class AlgebraProcessor {
 	
@@ -593,33 +591,46 @@ public class AlgebraProcessor {
 	}
 	
 	/**
-	 * Parses given String str and tries to evaluate it to a GeoText.
-	 * Returns null if something went wrong.
+	 * Parses given String str and tries to evaluate it to a GeoText. Returns
+	 * null if something went wrong.
+	 * @param str input string
+	 * @param createLabel true to label result
+	 * @param showErrors true to show error messages (only stacktrace otherwise)
+	 * @return resulting text
 	 */
-	public GeoText evaluateToText(String str, boolean createLabel) {
+	public GeoText evaluateToText(String str, boolean createLabel,
+			boolean showErrors) {
 		boolean oldMacroMode = cons.isSuppressLabelsActive();
 		cons.setSuppressLabelCreation(!createLabel);
 
 		GeoText text = null;
-		GeoElement [] temp = null;;
+		GeoElement[] temp = null;
 		try {
-			ValidExpression ve = parser.parseGeoGebraExpression(str);			
+			ValidExpression ve = parser.parseGeoGebraExpression(str);
 			temp = processValidExpression(ve);
 			text = (GeoText) temp[0];
 		} catch (CircularDefinitionException e) {
-			Application.debug("CircularDefinition");
-			app.showError("CircularDefinition");
-		} catch (Exception e) {		
-			e.printStackTrace();
-			app.showError("InvalidInput", str);
+			if (showErrors) {
+				Application.debug("CircularDefinition");
+				app.showError("CircularDefinition");
+			}
+		} catch (Exception e) {
+			if (showErrors) {
+				e.printStackTrace();
+				app.showError("InvalidInput", str);
+			}
 		} catch (MyError e) {
-			e.printStackTrace();
-			app.showError(e);
+			if (showErrors) {
+				e.printStackTrace();
+				app.showError(e);
+			}
 		} catch (Error e) {
-			e.printStackTrace();
-			app.showError("InvalidInput", str);
-		} 
-		
+			if (showErrors) {
+				e.printStackTrace();
+				app.showError("InvalidInput", str);
+			}
+		}
+
 		cons.setSuppressLabelCreation(oldMacroMode);
 		return text;
 	}
